@@ -30,7 +30,8 @@ from moss.ems.emslayer import EmsLayer
 from moss.ems.emsproject import EmsProject
 from moss.ems.emsservice import EmsServiceException, Service
 
-logger = logging.getLogger("ems_cli_export")
+logger = logging.getLogger(__name__)
+
 
 try:
     from osgeo import gdal
